CompressionVariant

Enum CompressionVariant 

pub enum CompressionVariant {
    BC7(BC7Settings),
}
Block compression variants supported by this crate.

Variants



BC7(BC7Settings)

BC7 compression with smooth alpha (RGBA)

Implementations

Source

impl CompressionVariant

pub const fn bytes_per_row(self, width: u32) -> u32

Returns the bytes per row for the given width.

The width is used to calculate how many blocks are needed per row, which is then multiplied by the block size. Width is rounded up to the nearest multiple of 4.

pub const fn blocks_byte_size(self, width: u32, height: u32) -> usize

Returns the byte size required for storing compressed blocks for the given dimensions.

The size is calculated based on the block compression format and rounded up dimensions. Width and height are rounded up to the nearest multiple of 4.